document.getElementById('pvalue-form').addEventListener('submit', function(e) {
  e.preventDefault();
  
  const pValue = parseFloat(document.getElementById('pvalue').value);
  const sampleSize = parseInt(document.getElementById('sample-size').value);
  const effectSize = parseFloat(document.getElementById('effect-size').value);
  
  const feedback = document.querySelector('.feedback');
  const suggestions = document.querySelector('.suggestions');
  
  feedback.innerHTML = '';
  suggestions.innerHTML = '';
  
  // Check for common p-value misuse patterns
  if (pValue < 0 || pValue > 1) {
    feedback.className = 'feedback error';
    feedback.textContent = 'Error: P-value must be between 0 and 1';
    return;
  }
  
  if (sampleSize < 30) {
    feedback.className = 'feedback warning';
    feedback.textContent = 'Warning: Small sample size may lead to unreliable results';
    suggestions.innerHTML = '<p>Consider increasing your sample size or using alternative statistical methods.</p>';
  }
  
  if (pValue < 0.05 && effectSize < 0.2) {
    feedback.className = 'feedback warning';
    feedback.textContent = 'Warning: Statistically significant but small effect size detected';
    suggestions.innerHTML += '<p>While your result is statistically significant, the practical significance may be limited. Consider reporting effect size and confidence intervals.</p>';
  }
  
  if (pValue >= 0.05 && pValue < 0.1) {
    feedback.className = 'feedback warning';
    feedback.textContent = 'Warning: Marginal significance detected';
    suggestions.innerHTML += '<p>Be cautious about interpreting marginal significance. Consider reporting exact p-values and confidence intervals.</p>';
  }
  
  if (!feedback.textContent) {
    feedback.className = 'feedback success';
    feedback.textContent = 'No major issues detected with your p-value interpretation';
    suggestions.innerHTML = '<p>Remember to always report effect sizes and confidence intervals alongside p-values.</p>';
  }
});